/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * 76571 Gaggenau
 * Phone: +49-7225-64-01
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.stealgsba.algorithmen.lib;

import java.util.ArrayList;
import java.util.List;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Diese Klasse speichert die Daten der Attributgruppe 'atg.sswSbaPassivierungFahrStreifen'.<p>
 * 
 * ber Getter und Setter kann auf die Daten zugegriffen werden.
 *
 * @version $Revision: 1.4 $ / $Date: 2013/04/10 11:49:24 $ / ($Author: Asal $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Rolf Asal
 *
 */
public class PassivierungFahrstreifen
{
	/**
	 * Liste der passivierten Fahrstreifen.
	 */
	private List<SystemObject> m_fahrStreifen = new ArrayList<SystemObject>();
	
	/**
	 * Default-Konstruktor ohne weitere Funktion.
	 */
	public PassivierungFahrstreifen()
	{		
	}
	
	/**
	 * Konstruktor mit bernahme der bergebenen Daten in die interne Struktur.
	 */
	public PassivierungFahrstreifen(ResultData rdata)
	{
		setdaten(rdata);
	}
	
	/**
	 * bernahme des bergebenen Datensatzes in die interne Struktur.
	 * 
	 * @param rdata Datensatz der Parameter.
	 */
	public void setdaten(ResultData rdata)
	{
		if (rdata != null)
		{
			if (m_fahrStreifen != null)
			{
				m_fahrStreifen.clear();
			}

			Data data = rdata.getData();
			if (data != null)
			{
				for (int i = 0; i < data.getItem("FahrStreifen").getReferenceArray("FahrStreifen").getLength(); i++)
				{
					addFahrstreifen(data.getItem("FahrStreifen").getReferenceArray("FahrStreifen").getReferenceValue(i).getSystemObject());
				}
			}
		}		
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() 
	{
		StringBuffer string = new StringBuffer();
		
		string.append(" " + m_fahrStreifen);
		
		return string.toString();
  }

	/**
	 * Gibt die Liste der passivierten Fahrstreifen zurck.
	 * 
	 * @return Liste der passivierten Fahrstreifen.
	 */
	public List<SystemObject> getFahrStreifen()
	{
		List<SystemObject> liste = new ArrayList<SystemObject>();
		
		liste.addAll(m_fahrStreifen);
		
		return liste;
	}
	/**
	 * Setzt die Liste der passivierten Fahrstreifen.
	 * 
	 * @param fahrStreifen zu setzende Liste der passivierten Fahrstreifen.
	 */
	public void setFahrStreifen(List<SystemObject> fahrStreifen)
	{
		m_fahrStreifen = fahrStreifen;
	}
	/**
	 * Fgt zu der Liste der passivierten Fahrstreifen den bergebenen Fahrstreifen, sofern
	 * er noch nicht in der Liste vorhanden ist, hinzu. 
	 * @param fahrStreifen Objekt Fahrstreifen.
	 */
	public void addFahrstreifen(SystemObject fahrStreifen)
	{
		if (fahrStreifen != null)
		{
			if (m_fahrStreifen == null)
			{
				m_fahrStreifen = new ArrayList<SystemObject>();
			}
			
			if (!m_fahrStreifen.contains(fahrStreifen))
			{
				m_fahrStreifen.add(fahrStreifen);
			}
		}
	}

	/**
	 * Lscht den bergebenen Fahrstreifen aus der Liste der passivierten Fahrstreifen.
	 *  
	 * @param fahrStreifen Objekt Fahrstreifen.
	 */
	public void delFahrstreifen(SystemObject fahrStreifen)
	{
		if (fahrStreifen != null)
		{			
			if (m_fahrStreifen.contains(fahrStreifen))
			{
				m_fahrStreifen.remove(fahrStreifen);
			}
		}
	}

	/**
	 * Prft, ob der bergebene Fahrstreifen in der Liste der passivierten Fahrstreifen enthalten ist.
	 * 
	 * @param objFs SystemObjekt Fahrstreifen.
	 * @return true wenn der bergebene Fahrstreifen passiviert ist, ansonsten false;
	 */
	public boolean isFahrStreifenPassiviert(SystemObject objFs)
	{
		if ((m_fahrStreifen != null) && (objFs != null))
		{
			if (m_fahrStreifen.contains(objFs))
				return true;			
		}
		
		return false;
	}

	/**
	 * Prft, ob die bergebene Liste mit Fahrstreifen zu der internen Liste unterschiedlich ist.
	 * 
	 * @param listeFs Liste mit Fahrstreifen.
	 * @return true wenn sich die bergebene Liste mit Fahrstreifen von der internen unterscheidet, ansonsten false;
	 */
	public boolean isUnterschied(List<SystemObject> listeFs)
	{
		if ((m_fahrStreifen != null) && (listeFs != null))
		{
			if (m_fahrStreifen.size() != listeFs.size())
				return true;
			
			for (int i = 0; i < listeFs.size(); i++)
			{
				if (!m_fahrStreifen.contains(listeFs.get(i)))
				{
					return true;
				}
			}			
		}
		
		return false;
	}

}
